@@ -39,17 +39,17 @@ class KGAPIDRIVE_EXPORT ChildReferenceFetchJob : public KGAPI2::FetchJob
   public:
     explicit ChildReferenceFetchJob(const QString &folderId,
                                     const AccountPtr &account,
-                                    QObject *parent = 0);
+                                    QObject *parent = nullptr);
     explicit ChildReferenceFetchJob(const QString &folderId,
                                     const QString &childId,
                                     const AccountPtr &account,
-                                    QObject *parent = 0);
+                                    QObject *parent = nullptr);
     virtual ~ChildReferenceFetchJob();
 
   protected:
-    void start() Q_DECL_OVERRIDE;
+    void start() override;
     KGAPI2::ObjectsList handleReplyWithItems(const QNetworkReply *reply,
-            const QByteArray &rawData) Q_DECL_OVERRIDE;
+            const QByteArray &rawData) override;
 
   private:
     class Private;
