@@ -28,8 +28,8 @@
 #include "utils.h"
 #include "private/queuehelper_p.h"
 
-#include <QtNetwork/QNetworkRequest>
-#include <QtNetwork/QNetworkReply>
+#include <QNetworkRequest>
+#include <QNetworkReply>
 
 using namespace KGAPI2;
 
@@ -67,7 +67,7 @@ void TaskMoveJob::Private::processNextTask()
     QStringList headers;
     const auto rawHeaderList = request.rawHeaderList();
     headers.reserve(rawHeaderList.size());
-    Q_FOREACH(const QByteArray &str, rawHeaderList) {
+    for (const QByteArray &str : qAsConst(rawHeaderList)) {
         headers << QLatin1String(str) + QLatin1String(": ") + QLatin1String(request.rawHeader(str));
     }
     qCDebug(KGAPIRaw) << headers;
@@ -93,7 +93,7 @@ TaskMoveJob::TaskMoveJob(const TasksList& tasks, const QString& taskListId,
     d(new Private(this))
 {
     d->tasksIds.reserve(tasks.size());
-    Q_FOREACH(const TaskPtr &task, tasks) {
+    for (const TaskPtr &task : tasks) {
         d->tasksIds << task->uid();
     }
     d->taskListId = taskListId;
